@@ -528,7 +528,7 @@ class ImagerStack(GenericStack):
             # check if it is a folder
             if os.path.isdir(filenames):
                 dirname = filenames
-                filenames = natsorted(glob(pjoin(dirname,'Frams*' + self.extension)))
+                filenames = natsorted(glob(pjoin(dirname,'Frames*' + self.extension)))
                 if not len(filenames): # try mj2's
                     self.extension = '.mj2'
                     filenames = natsorted(glob(pjoin(dirname,'Frames*' + self.extension)))
